using FitConnect.Models;
using FitConnect.Services.Models.v1.Submission;

namespace FitConnect.Interfaces.Subscriber;

public interface ISubscriber : IFitConnectClient {
    /// <summary>
    ///     Loads a list of available Submissions that were submitted to the subscriber.
    /// </summary>
    /// <param name="destinationId">unique identifier of the destination</param>
    /// <param name="offset">the offset of the list of submissions</param>
    /// <param name="limit">the limit of the list of submissions</param>
    /// <returns>List of available submissions for pickup</returns>
    public IEnumerable<SubmissionForPickupDto> GetAvailableSubmissions(string? destinationId = null,
        int offset = 0, int limit = 100);

    /// <summary>
    ///     Loads a single Submission by id.
    /// </summary>
    /// <param name="submissionId">unique identifier of a <see cref="Submission" /></param>
    /// <param name="skipSchemaTest"></param>
    /// <returns>A subscriber object with a submission</returns>
    public ISubscriberWithSubmission RequestSubmission(string? submissionId,
        bool skipSchemaTest = false);
}

public interface IFitConnectClient {
    /// <summary>
    ///     Receives the SecurityEventTokens for a given case
    /// </summary>
    /// <param name="caseId">ID of the case</param>
    /// <returns>List of the <see cref="SecurityEventToken" /></returns>
    public List<SecurityEventToken> GetStatusForSubmission(string caseId);
}
